@@ -36,7 +36,7 @@
 #if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
 #include <KNS3/QtQuickDialogWrapper>
 #else
-#include <KNSWidgets/QtQuickDialogWrapper>
+#include <KNSWidgets/Dialog>
 #endif
 #include <KHelpMenu>
 
@@ -46,6 +46,7 @@
 
 #include "langutils.h"
 #include "prefs.h"
+#include <QShortcut>
 
 KHangMan::KHangMan()
         : QMainWindow(),
@@ -56,7 +57,7 @@ KHangMan::KHangMan()
           m_randomInt(0),
           m_scoreMultiplyingFactor(1),
           m_netScore(0),
-          m_helpMenu(new KHelpMenu(NULL))
+          m_helpMenu(new KHelpMenu(nullptr))
 {
     setObjectName(QStringLiteral("KHangMan"));
 
@@ -82,6 +83,9 @@ KHangMan::KHangMan()
 
     //find the themes
     m_themeFactory.addTheme(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("khangman/themes/standardthemes.xml")));
+    
+    QShortcut *quitShortcut = new QShortcut(QKeySequence::Quit, this);
+    connect(quitShortcut, &QShortcut::activated, qApp, &QCoreApplication::quit);
 }
 
 KHangMan::~KHangMan()
@@ -91,7 +95,7 @@ KHangMan::~KHangMan()
     windowConfig.writeEntry("windowState", int(windowState()));
 
     delete m_view;
-    m_view = NULL;
+    m_view = nullptr;
 }
 
 void KHangMan::showAboutKHangMan()
@@ -511,14 +515,14 @@ void KHangMan::slotDownloadNewStuff()
 #if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
     KNS3::QtQuickDialogWrapper *dialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("khangman.knsrc"), this);
 #else
-    KNSWidgets::QtQuickDialogWrapper *dialog = new KNSWidgets::QtQuickDialogWrapper(QStringLiteral("khangman.knsrc"), this);
+    KNSWidgets::Dialog *dialog = new KNSWidgets::Dialog(QStringLiteral("khangman.knsrc"), this);
 #endif
     dialog->open();
 
 #if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 240, 0)
     connect(dialog, &KNS3::QtQuickDialogWrapper::closed, this, [this, dialog] {
 #else
-    connect(dialog, &KNSWidgets::QtQuickDialogWrapper::closed, this, [this, dialog] {
+    connect(dialog, &KNSWidgets::Dialog::finished, this, [this, dialog] {
 #endif
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QList<KNSCore::EntryInternal> entries = dialog->changedEntries();
@@ -578,7 +582,7 @@ void KHangMan::loadLanguageSpecialCharacters()
     openFileStream.close();
 }
 
+#include "moc_khangman.cpp"
 
 // kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
 // vim: set et sw=4 ts=4 cino=l1,cs,U1:
-
